"use strict";

var removeCSPHeader = false;

chrome.contextMenus.create({ id: "removecspheader", title: "Remove CSP Header", type: "checkbox", contexts: [ "all" ] });

addListeners();

function addListeners()
{
    /* Browser action listener */
    
    chrome.browserAction.onClicked.addListener(
    function(tab)
    {
        chrome.tabs.create({ url: chrome.runtime.getURL("container.html") },
        function(tab)
        {
            window.setTimeout(
            function()
            {
                chrome.tabs.sendMessage(tab.id, { type: "loadPage" },{ frameId: 0 });
            },200);
        });
    });
    
    /* Context menu listener */
    
    chrome.contextMenus.onClicked.addListener(
    function(info,tab)
    {
        switch (info.menuItemId)
        {
            /* Page or button context menu */
            
            case "removecspheader":
                
                removeCSPHeader = !removeCSPHeader;
                
                chrome.contextMenus.update("removecspheader",{ checked: removeCSPHeader });

                break;
        }
    });
    
    /* Web request listeners */
    
    chrome.webRequest.onHeadersReceived.addListener(
    function(details)
    {
        var i;
        
        if (details.parentFrameId == 0 && details.type == "sub_frame")  /* tiled frame - parent frame is top-level frame in layout tab */
        {
            for (i = details.responseHeaders.length-1; i >= 0; i--)
            {
                if (details.responseHeaders[i].name.toLowerCase() == "x-frame-options")
                {
                    details.responseHeaders.splice(i,1);
                }
                else if (details.responseHeaders[i].name.toLowerCase() == "content-security-policy")
                {
                    if (removeCSPHeader)  /* remove CSP Header */
                    {
                        details.responseHeaders.splice(i,1);
                    }
                    else  /* remove frame-ancestors directive */
                    {
                        details.responseHeaders[i].value = details.responseHeaders[i].value.replace(/frame-ancestors[^;]*(;|$)/g,"");
                    }
                }
            }
            
            return { responseHeaders: details.responseHeaders };
        }
    }
    , { urls: ["http://*/*", "https://*/*"] }, ["blocking", "responseHeaders"]);
}
